% Copyright 2017 by Natalie Weber and Erin Guntly
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%
%   http://www.latex-project.org/lppl.txt
%
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
%
\NeedsTeXFormat{LaTeX2e}[1994/06/01]%
\ProvidesClass{ubcopl}[2017/03/26 v1.0 UBC Occasional Papers in Linguistics class]%

% Versions:
% v1.0	- new template



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%===GLOBAL DECLARATIONS===%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%===CONDITIONALS===%
	
	\newif\iffinal\finalfalse % if titlepage.tex exists, include it
	\newif\iffinaldigital\finaldigitalfalse

% Using \audiofilestrue print `` (including audio files) on copyright page			 
	\newif\ifaudiofiles\audiofilesfalse % default = no audiofiles
 
 
%===OPTIONS DECLARATIONS===%

	\LoadClass[twoside,11pt,openright]{memoir}% defaults 

	% Possible options are: 
		% [final] - includes finalformatting.tex, if available
		% [finaldigital] - calls [final] package option and also includes hyperref
		% Anything else, e.g. [draft], is passed to memoir.

	\DeclareOption{final}{\finaltrue}
	\DeclareOption{finaldigital}{\finaltrue\finaldigitaltrue}
	\DeclareOption*{% pass unknown options to memoir
	  \PassOptionsToClass{\CurrentOption}{memoir}%
	}%

	\ProcessOptions\relax


%===PACKAGES===%

	\RequirePackage[T1]{fontenc} % must precede fontspec, for \copyright on copyright page
	\RequirePackage{fontspec}

	\RequirePackage{emptypage} %removes headers from empty pages

	\RequirePackage{ragged2e} % footnotes and the default titlepage use \RaggedRight

	\RequirePackage[longnamesfirst,sort&compress]{natbib}
	
	\RequirePackage{expex}

	% Include hyperref only if [finaldigital] package option is used.
	\iffinaldigital
	
	% [hidelinks] will remove all links, but it is only in newer versions of hyperref,
	%	so I used colorlinks=false,pdfborder={0 0 0} instead
		\RequirePackage{hyperref}
		\RequirePackage{memhfixc}% required! hyperref does not play well with memoir
		\hypersetup{breaklinks,%
				   colorlinks=false,pdfborder={0 0 0},%
		                plainpages=false,%
		                pdfpagelabels,%
				bookmarks,bookmarksnumbered,% show bookmarks bar
		                pdfstartview=FitH}
	\fi
	
	
%===GLOBAL SETTINGS===%

	\widowpenalty10000
	\clubpenalty10000
	\sloppy
	\raggedbottom % because of footnotes
	
	
%===MACROS===%

% To test if an argument to a macro is empty:
	\global\long\def\tlist@if@empty@nTF #1{%
		\expandafter\ifx\expandafter\\\detokenize{#1}\\%
			\expandafter\@firstoftwo%
		\else%
			\expandafter\@secondoftwo%
		\fi%
	}%
	
% Commands for font formatting
	
	% \headerfont initialized to do nothing, but I included it in headers.
	% It can be redefined or let to anything.
	\def\headerfont{\relax}
	
	% For small words on title page. Initializes to nothing.
	\newcommand{\smallword}[1]{#1}
 
% new mark for subchapters

	\newcommand{\subchaptermark}[1]{}

% Commands to control how subtitles appear.
% For each, arg #1 = main title, #2 = sub title

	\newcommand{\doublechaptitleformat}[2]{{#1\\{\huge#2}}}% on chapter first page
	\newcommand{\doublechaptocformat}[2]{{\normalsize#1}\\{\textendash{}\small#2}}% in ToC
	
 
% Symbol footnotes. Usage: \symbolfootnote[4]{This is the footnote text.}
% The optional argument is a number 1-9, each of which picks out a different symbol.
	\long\def\symbolfootnote[#1]#2{\begingroup%
	\def\thefootnote{\fnsymbol{footnote}}\footnote[#1]{#2}\endgroup}

% For title page and copyright page

\def\@subtitle{\relax}

\def\@editor{\relax}
\def\@translator{\relax}
\def\@recorder{\relax}
\def\@contributorA{\relax}
\def\@contributorB{\relax}
\def\@contributorC{\relax}

% default pre-text before editors, etc.
\def\@preeditor{Edited by}
\def\@pretranslator{Translated by}
\def\@prerecorder{Recorded by}
\def\@precontributorA{\relax}
\def\@precontributorB{\relax}
\def\@precontributorC{\relax}

\newcommand{\subtitle}[1]{\gdef\@subtitle{#1}}

\newcommand{\editor}[1]{\gdef\@editor{#1}}
\newcommand{\translator}[1]{\gdef\@translator{#1}}
\newcommand{\recorder}[1]{\gdef\@recorder{#1}}
\newcommand{\contributorA}[1]{\gdef\@contributorA{#1}}
\newcommand{\contributorB}[1]{\gdef\@contributorB{#1}}
\newcommand{\contributorC}[1]{\gdef\@contributorC{#1}}

\newcommand{\preeditor}[1]{\gdef\@preeditor{#1}}
\newcommand{\pretranslator}[1]{\gdef\@pretranslator{#1}}
\newcommand{\prerecorder}[1]{\gdef\@prerecorder{#1}}
\newcommand{\precontributorA}[1]{\gdef\@precontributorA{#1}}
\newcommand{\precontributorB}[1]{\gdef\@precontributorB{#1}}
\newcommand{\precontributorC}[1]{\gdef\@precontributorC{#1}}



\def\Fcopyrightinfo{\relax}
\def\@isbn{\relax}
\def\@edition{\relax}
\def\@pubdate{\relax}
\def\@volume{\relax}
\def\@printing{\relax}
\def\@managingeditor{\relax}
\def\@assistanteditor{\relax}

\newcommand{\copyrightinfo}[1]{\gdef\@copyrightinfo{#1}}
\newcommand*{\isbn}[1]{\gdef\@isbn{#1}}
\newcommand*{\edition}[1]{\gdef\@edition{#1}}
\newcommand*{\pubdate}[1]{\gdef\@pubdate{#1}}
\newcommand*{\volume}[1]{\gdef\@volume{#1}}
\newcommand*{\printing}[1]{%
	\ifcase#1
		\relax %case 0
		\or\gdef\@printing{10  9  8  7  6  5  4  3  2  1}%case 1
		\or\gdef\@printing{10  9  8  7  6  5  4  3  2}%case 2
		\or\gdef\@printing{10  9  8  7  6  5  4  3}%case 3
		\or\gdef\@printing{10  9  8  7  6  5  4}%case 4
		\or\gdef\@printing{10  9  8  7  6  5}%case 5
		\or\gdef\@printing{10  9  8  7  6}%case 6
		\or\gdef\@printing{10  9  8  7}%case 7
		\or\gdef\@printing{10  9  8}%case 8
		\or\gdef\@printing{10  9}%case 9
		\or\gdef\@printing{10}%case 10
		\else\gdef\@printing{10  9  8  7  6  5  4  3  2  1}% else if none of the above
	\fi
}
\newcommand*{\managingeditor}[2][Managing Editor]{\gdef\@managingeditor{#1, #2}}
\newcommand*{\assistanteditor}[2][Assistant Editors]{\gdef\@assistanteditor{#1, #2}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%===SET FONT REQUIREMENTS===%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



	



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%===SET PAGE LAYOUT===%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

									
%===PAGE MARGINS===%

	\setstocksize{9in}{6in}
	\settrimmedsize{\stockheight}{\stockwidth}{*}
	\settrims{0pt}{0pt}
	\setlrmarginsandblock{1.25in}{.5in}{*}
	\setulmarginsandblock{1.5in}{1.25in}{*}
	\setheadfoot{1in}{.5in}
	\setmarginnotes{0in}{0in}{0in}
	\checkandfixthelayout
							
%===HEADERS===%

	% page style for backmatter (folios in bottom outer corner; header rule but no text)
	\makepagestyle{oplbackmatter}
		
		\makeevenhead{oplbackmatter}{}{}{}
		\makeoddhead{oplbackmatter}{}{}{}
		\makeheadrule{oplbackmatter}{\oplbackmatterheadrunwidth}{\normalrulethickness}
			% \oplheadingheadrunwidth defaults to \textwidth; EG originally had \textwidth
			% \normalrulethickness = 0.4pt; EG originally had 0.5 
			
		\makeevenfoot{oplbackmatter}{\thepage}{}{}
		\makeoddfoot{oplbackmatter}{}{}{\thepage}

	% page style for normal opl headings (same as backmatter, but adds header text)
	\copypagestyle{oplheading}{oplbackmatter}
		% set left marks to chapter title
		\makepsmarks{oplheading}{%
			
			% The memoir definition for \chapter calls \chaptermark{ARG}, where 
			% 	ARG = the second optional argument of \chapter (if there is one), else
			%	the first/only optional argument of \chapter (if there is one), else
			% 	the chapter title.
			
			% The ubcopl class defines a new \subchaptermark, which is called in a new
			% definition for \subchapter. So we can set that with \markright. Note that 
			% \rightmark takes the right argument from the FIRST \markright or \markboth 
			% called, so we need to call \subchaptermark before \chaptermark, just in case.

			\clearmark{section}
			\renewcommand*{\subchaptermark}[1]{\markright{##1}}%
			\renewcommand*{\chaptermark}[1]{\markboth{##1}{##1}}%
		}
	
		% chapter name in header
		\makeevenhead{oplheading}{{\headerfont\leftmark}}{}{}
		\makeoddhead{oplheading}{}{}{{\headerfont\rightmark{}}}	

	% defaults
	\pagestyle{oplbackmatter}

	
% page style defines, e.g. \chaptermark, so that it picks up the title, or the title and number
% define \chaptermark in terms of markboth or markright

	% \markboth{left}{right} 	sets two of these markers to left and right
	% \markright{right} 		sets one marker to right
	
	% \leftmark contains the left argument of the last \markboth on the page
	% \rightmark contains the right argument of the first \markboth or \markright
	
	

%===CHAPTER AND SECTION SETTINGS===%

% Must set \beforechapskip before calling \chapterstyle!

	\setlength\beforechapskip{2\baselineskip}% default = 50pt
	\chapterstyle{companion} % from memoir class; prints chapter name, number, title


% Revising the \chapter command from memoir to take an optional last argument, 
%	like \chapter[toc][head]{maintitle}[subtitle]

\renewcommand{\@m@mchapter}[1][]{%
	\def\ch@pt@c{#1}% capture first optional arg
	% We hi-jack memoir's code at this point to check if there is a subtitle.
	\@ifnextchar[{\@chksubchapter}{\@chksubchapter[]}%
	% original: \@ifnextchar[{\@chapter}{\@chapter[]}%
}%

\def\@chksubchapter[#1]#2{% #1 = for header; #2 = main title
	\@ifnextchar[{\@subchapter[#1]{#2}}% if subtitle
	{\@chapter[#1]{#2}}% if no subtitle, call \@chapter like normal
}%

% \@subchapter is new to ubcopl class. It is based on memoir's \@chapter macro (below)
% but takes an extra argument, which it typesets appropriately. Also, it sets a new
% \subchaptermark, for the headings.

\def\@subchapter[#1]#2[#3]{%
  \m@mpn@new@chaptrue%
  \m@mpn@new@schapfalse%
  \def\f@rbdy{\doublechaptitleformat{#2}{#3}}% ??? NW {#2}%
  \ifx\ch@pt@c\@empty % no optional args
    \def\f@rtoc{\doublechaptocformat{#2}{#3}}%NW {#2}%
    \def\f@rhdr{#2} % ???
  \else                  % at least one opt arg
    \def\f@rtoc{\doublechaptocformat{#2}{#3}}%NW \let\f@rtoc\ch@pt@c
    \ifx\@empty#1\@empty
      \let\f@rhdr\ch@pt@c
    \else
      \def\f@rhdr{#1}
    \fi
  \fi
  \m@m@Andfalse
  \ifnum \c@secnumdepth >\m@ne
    \if@mainmatter
      \m@m@Andtrue
    \fi
  \fi
  \ifm@m@And
    \refstepcounter{chapter}%
  \fi
  \ifartopt
    \@makechapterhead{\doublechaptitleformat{#2}{#3}}%NW {#2}%
    \@afterheading
    \chaptermark{\f@rhdr}%
    \subchaptermark{#3}%NW
  \else
    \chaptermark{\f@rhdr}
    \subchaptermark{#3}%NW
    \insertchapterspace
    \if@twocolumn
      \@topnewpage[\@makechapterhead{\doublechaptitleformat{#2}{#3}}]%NW {#2}
    \else
      \@makechapterhead{\doublechaptitleformat{#2}{#3}}%NW {#2}
    \fi
    \@afterheading
  \fi
  \@nameuse{chapter@f@rtoc@before@write@hook}%     
  \mempreaddchaptertotochook%
  \ifm@m@And
    \ifanappendix
      \addcontentsline{toc}{appendix}{%
        \protect\chapternumberline{\thechapter}\f@rtoc}%
      \memappchapinfo{\thechapter}{\f@rtoc}{\f@rhdr}{#2}%
    \else
      \addcontentsline{toc}{chapter}{%
        \protect\chapternumberline{\thechapter}\f@rtoc}%
      \memchapinfo{\thechapter}{\f@rtoc}{\f@rhdr}{#2}%
    \fi
  \else
    \addcontentsline{toc}{chapter}{\f@rtoc}%
    \ifanappendix
      \memappchapinfo{}{\f@rtoc}{\f@rhdr}{#2}%
    \else
      \memchapinfo{}{\f@rtoc}{\f@rhdr}{#2}%
    \fi
  \fi
  \mempostaddchaptertotochook%
  \ifheadnameref\M@gettitle{\f@rhdr}\else\M@gettitle{\f@rtoc}\fi%
  \memendofchapterhook%
}



% Since \@subchapter is modified from \@chapter, I will also copy the code for
% \@chapter here. If memoir ever updates to change % the definition of \@chapter, 
%at least chapters and subchapters for for the ubcopl class will behave the same!
% This is from {memoir}[2016/05/16 v3.7f configurable book, report, article document class]

\def\@chapter[#1]#2{%
  \m@mpn@new@chaptrue%
  \m@mpn@new@schapfalse%
  \def\f@rbdy{#2}%
  \ifx\ch@pt@c\@empty % no optional args
    \def\f@rtoc{#2}%
    \def\f@rhdr{#2}%
  \else                  % at least one opt arg
    \let\f@rtoc\ch@pt@c
    \ifx\@empty#1\@empty
      \let\f@rhdr\ch@pt@c
    \else
      \def\f@rhdr{#1}%
    \fi
  \fi
  \m@m@Andfalse
  \ifnum \c@secnumdepth >\m@ne
    \if@mainmatter
      \m@m@Andtrue
    \fi
  \fi
  \ifm@m@And
    \refstepcounter{chapter}%
  \fi
  \ifartopt
    \@makechapterhead{#2}%
    \@afterheading
    \chaptermark{\f@rhdr}%
  \else
    \chaptermark{\f@rhdr}
    \insertchapterspace
    \if@twocolumn
      \@topnewpage[\@makechapterhead{#2}]%
    \else
      \@makechapterhead{#2}%
    \fi
    \@afterheading
  \fi
  \@nameuse{chapter@f@rtoc@before@write@hook}%     
  \mempreaddchaptertotochook%
  \ifm@m@And
    \ifanappendix
      \addcontentsline{toc}{appendix}{%
        \protect\chapternumberline{\thechapter}\f@rtoc}%
      \memappchapinfo{\thechapter}{\f@rtoc}{\f@rhdr}{#2}%
    \else
      \addcontentsline{toc}{chapter}{%
        \protect\chapternumberline{\thechapter}\f@rtoc}%
      \memchapinfo{\thechapter}{\f@rtoc}{\f@rhdr}{#2}%
    \fi
  \else
    \addcontentsline{toc}{chapter}{\f@rtoc}%
    \ifanappendix
      \memappchapinfo{}{\f@rtoc}{\f@rhdr}{#2}%
    \else
      \memchapinfo{}{\f@rtoc}{\f@rhdr}{#2}%
    \fi
  \fi
  \mempostaddchaptertotochook%
  \ifheadnameref\M@gettitle{\f@rhdr}\else\M@gettitle{\f@rtoc}\fi%
  \memendofchapterhook%
}

% Now we modify memoir's code for starred chapters (\chapter*{})

\renewcommand{\@m@mschapter}[2][\@empty]{%
	\@ifnextchar[%
		{\@sub@m@mschapter[#1]{#2}}% if subtitle
		{\@orig@m@mschapter[#1]{#2}}% if no subtitle
}

\def\@sub@m@mschapter[#1]#2[#3]{%
  \@schapter{\doublechaptitleformat{#2}{#3}}%NW {#2}%
  \ifx \@empty#1
    \def\f@rhdr{#2}%
  \else%                    opt arg
    \def\f@rhdr{#1}%
    \setcounter{secnumdepth}{-10}%
    \chaptermark{#1}%
    \subchaptermark{#3}% NW
    \setcounter{secnumdepth}{\value{maxsecnumdepth}}%
  \fi
  \ifanappendix
    \memappchapstarinfo{\f@rhdr}{#2}%
  \else
    \memchapstarinfo{\f@rhdr}{#2}%
  \fi
  \ifheadnameref\M@gettitle{\f@rhdr}\else\M@gettitle{#2}\fi
}

\def\@orig@m@mschapter[#1]#2{%
  \@schapter{#2}%
  \ifx \@empty#1
    \def\f@rhdr{#2}%

  \else%                    opt arg
    \def\f@rhdr{#1}%
    \setcounter{secnumdepth}{-10}%
    \chaptermark{#1}%
    \setcounter{secnumdepth}{\value{maxsecnumdepth}}%
  \fi
  \ifanappendix
    \memappchapstarinfo{\f@rhdr}{#2}%
  \else
    \memchapstarinfo{\f@rhdr}{#2}%
  \fi
  \ifheadnameref\M@gettitle{\f@rhdr}\else\M@gettitle{#2}\fi
}

% Here is the original code for \@m@mschapter, commented out.
%\newcommand{\@m@mschapter}[2][\@empty]{%
%  \@schapter{#2}%
%  \ifx \@empty#1
%    \def\f@rhdr{#2}%
%  \else%                    opt arg
%    \def\f@rhdr{#1}%
%    \setcounter{secnumdepth}{-10}%
%    \chaptermark{#1}%
%    \setcounter{secnumdepth}{\value{maxsecnumdepth}}%
%  \fi
%  \ifanappendix
%    \memappchapstarinfo{\f@rhdr}{#2}%
%  \else
%    \memchapstarinfo{\f@rhdr}{#2}%
%  \fi
%  \ifheadnameref\M@gettitle{\f@rhdr}\else\M@gettitle{#2}\fi
%}


%===FOOTNOTE SETTINGS===%

\renewcommand\foottextfont{\footnotesize\RaggedRight}




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%===BIBLIOGRAPHY===%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\setlength{\bibsep}{.5\baselineskip} % natbib spacing


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%===TITLE PAGE===%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%incorporated 2019 by Marianne Huijsmans from draft by Erin Guntly

\newcommand{\opltitle}{\begingroup
	\setlength{\parskip}{0pt}
	\setlength{\parindent}{0pt}
	\thispagestyle{empty}
	\centering

	\vspace{1.5in} % space above title
	

	\linespread{1}%\selectfont	% if # < 1, Title will have lines closer together
	{\huge\@title\par}
	\vspace{.15in}
	{\LARGE\@subtitle\par}%\titlefont
	
	\vspace{.75in}
	
	{\LARGE\smallword{\textit{by}} \@author\par}%\titlefont
	\linespread{1}%\selectfont	% reset linespacing
	
	\vspace{.75in}

    \if\@editor\relax {}  %must be if not ifx.  whatever is after \relax and before \else will be typeset if the tex file does not call the command
    \else
    {\itshape\@preeditor\par}
	{\large\@editor\par}%\titlefont
	\vspace{.1in}
	\fi

	\if\@translator\relax {}
	\else
	{\itshape\@pretranslator\par}
	{\large\@translator\par}%\titlefont
	\vspace{.1in}
	\fi

 \if\relax\@recorder\relax {}   
    \else 
	{\itshape\@prerecorder\par}
	{\large\@recorder\par}%\titlefont
	\fi
	
	\vfill
	\rule{0.4\textwidth}{0.4pt}
	
		\vspace{.25in}
	
University of British Columbia \\ Occasional Papers in Linguistics
	
	\linespread{1}%\selectfont % reset linespacing
	
		\vspace{.25in}
	
	{\large\scshape \@date\par}
	\vfill\null
	\clearpage
\endgroup}




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%===COPYRIGHT PAGE===%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\newcommand{\pubinfopage}{\begingroup
\thispagestyle{empty}
\hyphenpenalty=10000
\raggedright

\setlength{\parindent}{0pt}%
\setlength{\parskip}{\bigskipamount}% EG originally had \vspace{12pt}, which is roughly = \bigskip

\vspace*{\fill}

\@copyrightinfo

ISBN \@isbn\\
\@edition\space Edition, published \@pubdate.\\
UBCOPL Vol.\ \@volume.

\@printing

Printed by University of British Columbia Occasional Papers in Linguistics, Vancouver, BC, Canada.\\
\@managingeditor\\
\@assistanteditor

For information and resources related to this volume%
\ifaudiofiles 
	\space (including audio files)%
	\else\relax
\fi, or to purchase additional volumes, please visit UBCOPL at %NW removed \\
 \hbox{http://publications.linguistics.sites.olt.ubc.ca}

\endgroup}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%===FINAL FORMATTING===%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Load final formatting if [final] package option selected
% Must be loaded before title and copyright page are printed
	\iffinal
		\IfFileExists{./finalformatting.tex}%
			{\AtBeginDocument{\input{./finalformatting.tex}}}% true
			{\relax}% false
		\else\relax
	\fi


% Print title page and copyright page
\AtBeginDocument{%
	\@ifpackageloaded{expex}{\gathertags}{\relax}	% from expex

	\opltitle		% title page
	\pubinfopage	% copyright page
	\null
	\clearpage
}


\endinput

If we really wanted \frontmatter to call a particular page style, we could redefine \@memfront, etc.

\newcommand{\@memfront}{%
  \@smemfront\pagenumbering{roman}}
  
\newcommand{\@memmain}{%
  \@smemmain\pagenumbering{arabic}}
  
\newcommand{\backmatter}{%
  \ifartopt
    \clearpage
  \else
    \if@openright
      \cleardoublepage
    \else
      \clearpage
    \fi
  \fi
  \@mainmatterfalse
  \setcounter{secnumdepth}{-10}
  \ifartopt\else
    \@memback@floats
  \fi}